@@ -16,7 +16,7 @@ class PGFunction(ReplaceableEntity):
     def from_sql(cls, sql: str) -> Optional[PGFunction]:
         """ Create an instance of PGFunction from a blob of sql """
         template = (
-            "create{:s}or{:s}replace{:s}function{:s}{schema}.{signature}{:s}returns{:s}{definition}"
+            "create{}function{:s}{schema}.{signature}{:s}returns{:s}{definition}"
         )
         result = parse(template, sql.strip(), case_sensitive=False)
         if result is not None:
