@@ -17,8 +17,7 @@ class PGView(ReplaceableEntity):
     def from_sql(cls, sql: str) -> Optional[PGView]:
         """Create an instance of PGFunction from a blob of sql"""
         templates = [
-            "create{:s}or{:s}replace{:s}view{:s}{schema}.{signature}{:s}as{:s}{definition}",
-            "",
+            "create{}view{:s}{schema}.{signature}{:s}as{:s}{definition}",
         ]
         for template in templates:
             result = parse(template, sql, case_sensitive=False)
